@@ -102,7 +102,7 @@ sub union_tables {
             my $default_alias = 'U_TBL_' . $unique_char++;
             my $alias = $ax->alias( $union, 'union', $union_table, $default_alias );
             if ( length $alias ) {
-                $qt_union_table = $union_table . " AS " . $ax->prepare_identifier( $alias );
+                $qt_union_table = $union_table . $sf->{i}{" AS "} . $ax->prepare_identifier( $alias );
             }
             $sf->{d}{col_names}{$union_table} = $ax->column_names( $qt_union_table );
         }
@@ -123,7 +123,7 @@ sub union_tables {
     my $dummy_identifier = 'UNION_ALL_' . join( '_', @{$union->{used_tables}} ); ##
     my $alias = $ax->alias( $union, 'union', $dummy_identifier, $dummy_identifier );
     if ( length $alias ) {
-        $qt_table .= " AS " . $ax->prepare_identifier( $alias );
+        $qt_table .= $sf->{i}{" AS "} . $ax->prepare_identifier( $alias );
     }
     # column names in the result-set of a UNION are taken from the first query.
     my $qt_columns = $union->{subselect_data}[0][1];
